@@ -59,6 +59,7 @@ from ._jsii import *
 __all__ = [
     "pwed_bastion",
     "pwed_static_site",
+    "pwed_ttl",
 ]
 
 publication.publish()
@@ -66,3 +67,4 @@ publication.publish()
 # Loading modules to ensure their types are registered with the jsii runtime library
 from . import pwed_bastion
 from . import pwed_static_site
+from . import pwed_ttl
